@@ -20,7 +20,7 @@ def _translate(model):
 def _match(pattern, model):
     if '*' in pattern and '.*' not in pattern:
         pattern = pattern.replace('*','.*')
-    return re.match(pattern.lower().replace('%','.*'), model)
+    return re.match('^%s$' % pattern.lower().replace('%','.*'), model)
             
 # MariaDBReader
 
